@@ -1,7 +1,7 @@
 /*
    Virtual File System switch code
 
-   Copyright (C) 1995-2024
+   Copyright (C) 1995-2025
    Free Software Foundation, Inc.
 
    Written by: 1995 Miguel de Icaza
@@ -77,10 +77,10 @@ extern vfs_class *current_vfs;
 
 /*** global variables ****************************************************************************/
 
-struct vfs_dirent *mc_readdir_result = NULL;
-GPtrArray *vfs__classes_list = NULL;
-GString *vfs_str_buffer = NULL;
-vfs_class *current_vfs = NULL;
+MC_MOCKABLE struct vfs_dirent *mc_readdir_result = NULL;
+MC_MOCKABLE GPtrArray *vfs__classes_list = NULL;
+MC_MOCKABLE GString *vfs_str_buffer = NULL;
+MC_MOCKABLE vfs_class *current_vfs = NULL;
 
 /*** file scope macro definitions ****************************************************************/
 
@@ -201,10 +201,8 @@ vfs_get_openfile (int handle)
         return NULL;
 
     h = (struct vfs_openfile *) g_ptr_array_index (vfs_openfiles, handle - VFS_FIRST_HANDLE);
-    if (h == NULL)
-        return NULL;
-
-    g_assert (h->handle == handle);
+    if (h != NULL)
+        g_assert (h->handle == handle);
 
     return h;
 }
@@ -221,7 +219,6 @@ vfs_test_current_dir (const vfs_path_t *vpath)
             && my_stat.st_ino == my_stat2.st_ino && my_stat.st_dev == my_stat2.st_dev);
 }
 
-
 /* --------------------------------------------------------------------------------------------- */
 /*** public functions ****************************************************************************/
 /* --------------------------------------------------------------------------------------------- */
@@ -243,7 +240,6 @@ vfs_free_handle (int handle)
     }
 }
 
-
 /* --------------------------------------------------------------------------------------------- */
 /** Find VFS class by file handle */
 
@@ -301,7 +297,7 @@ vfs_new_handle (struct vfs_class *vclass, void *fsinfo)
 int
 vfs_ferrno (struct vfs_class *vfs)
 {
-    return vfs->ferrno ? (*vfs->ferrno) (vfs) : E_UNKNOWN;
+    return vfs->ferrno != NULL ? vfs->ferrno (vfs) : E_UNKNOWN;
     /* Hope that error message is obscure enough ;-) */
 }
 
@@ -311,7 +307,7 @@ gboolean
 vfs_register_class (struct vfs_class *vfs)
 {
     if (vfs->init != NULL)      /* vfs has own initialization function */
-        if (!vfs->init (vfs))   /* but it failed */
+        if (vfs->init (vfs) == 0)       /* but it failed */
             return FALSE;
 
     g_ptr_array_add (vfs__classes_list, vfs);
@@ -642,7 +638,7 @@ vfs_setup_cwd (void)
 
     if (vfs_get_raw_current_dir () == NULL)
     {
-        current_dir = g_get_current_dir ();
+        current_dir = my_get_current_dir ();
         vfs_set_raw_current_dir (vfs_path_from_str (current_dir));
         g_free (current_dir);
 
@@ -661,7 +657,7 @@ vfs_setup_cwd (void)
     me = vfs_path_get_last_path_vfs (vfs_get_raw_current_dir ());
     if ((me->flags & VFSF_LOCAL) != 0)
     {
-        current_dir = g_get_current_dir ();
+        current_dir = my_get_current_dir ();
         tmp_vpath = vfs_path_from_str (current_dir);
         g_free (current_dir);
 
